@@ -9,10 +9,9 @@ def config_logger(logger: Logger) -> None:
     Configure global logger add handlers and set formatters.
 
     :param logger:
-    :type: Logger
     """
     logger.setLevel(DEBUG)
-    file_hand = RotatingFileHandler(filename=path.join(environ.get('TEMP', ''), 'dcspy.log'), mode='a', maxBytes=1024 * 1024, backupCount=1)
+    file_hand = RotatingFileHandler(filename=path.join(environ.get('TEMP', ''), 'dcspy.log'), mode='a', encoding='utf-8', maxBytes=5 * 1024 * 1024, backupCount=1)
     file_hand.setLevel(DEBUG)
     file_hand.setFormatter(Formatter('%(asctime)s | %(name)-17s | %(levelname)-7s | %(threadName)-10s | %(message)s / %(funcName)s:%(lineno)d'))
     stream_hand = StreamHandler()
